@@ -14,8 +14,8 @@ from urllib.parse import urlparse
 from tuxrun import __version__
 from tuxrun.assets import get_rootfs, get_test_definitions, ROOTFS
 from tuxrun.devices import Device
-import tuxrun.templates as templates
-from tuxrun.tuxmake import TuxMakeBuild
+from tuxrun.tests import Test
+from tuxrun.tuxmake import TuxBuildBuild, TuxMakeBuild
 from tuxrun.utils import TTYProgressIndicator
 
 
@@ -25,7 +25,9 @@ from tuxrun.utils import TTYProgressIndicator
 def filter_options(options):
     keys = [
         "device",
+        "tuxbuild",
         "tuxmake",
+        "timeouts",
         "device_dict",
         "definition",
         "runtime",
@@ -62,6 +64,13 @@ def pathnone(string):
     return path.expanduser().resolve()
 
 
+def tuxbuild_url(s):
+    try:
+        return TuxBuildBuild(s.rstrip("/"))
+    except TuxBuildBuild.Invalid as e:
+        raise argparse.ArgumentTypeError(str(e))
+
+
 def tuxmake_directory(s):
     try:
         return TuxMakeBuild(s)
@@ -90,7 +99,7 @@ class ListTestsAction(argparse.Action):
         super().__init__(option_strings, dest=dest, default=default, nargs=0, help=help)
 
     def __call__(self, parser, namespace, values, option_string=None):
-        parser._print_message("\n".join(templates.tests_list()) + "\n", sys.stderr)
+        parser._print_message("\n".join(Test.list()) + "\n", sys.stderr)
         parser.exit()
 
 
@@ -101,6 +110,21 @@ class KeyValueAction(argparse.Action):
             getattr(namespace, self.dest)[key] = value
 
 
+class KeyValueIntAction(argparse.Action):
+    def __call__(self, parser, namespace, values, option_string=None):
+        KEYS = ["deploy", "boot"] + Test.list()
+        for value in values:
+            key, value = value.split("=")
+            if key not in KEYS:
+                raise argparse.ArgumentError(self, f"Invalid timeout '{key}'")
+            try:
+                getattr(namespace, self.dest)[key] = int(value)
+            except ValueError:
+                raise argparse.ArgumentError(
+                    self, f"Invalid value for {key} timeout: '{value}'"
+                )
+
+
 class UpdateCacheAction(argparse.Action):
     def __init__(
         self, option_strings, help, dest=argparse.SUPPRESS, default=argparse.SUPPRESS
@@ -131,13 +155,6 @@ def setup_parser() -> argparse.ArgumentParser:
     parser.add_argument(
         "--version", action="version", version=f"%(prog)s, {__version__}"
     )
-    parser.add_argument(
-        "--device",
-        default=None,
-        metavar="NAME",
-        help="Device type",
-        choices=Device.list(),
-    )
 
     group = parser.add_argument_group("listing")
     group.add_argument(
@@ -188,6 +205,13 @@ def setup_parser() -> argparse.ArgumentParser:
     artefact("rootfs")
     artefact("scp-fw")
     artefact("scp-romfw")
+    group.add_argument(
+        "--tuxbuild",
+        metavar="URL",
+        default=None,
+        type=tuxbuild_url,
+        help="URL of a TuxBuild build",
+    )
     group.add_argument(
         "--tuxmake",
         metavar="DIRECTORY",
@@ -207,14 +231,13 @@ def setup_parser() -> argparse.ArgumentParser:
         action=KeyValueAction,
         nargs="+",
     )
-
     group.add_argument(
         "--tests",
         nargs="+",
         default=[],
         metavar="T",
         help="test suites",
-        choices=templates.tests_list(),
+        choices=Test.list(),
     )
     group.add_argument(
         "command",
@@ -223,9 +246,25 @@ def setup_parser() -> argparse.ArgumentParser:
     )
 
     group = parser.add_argument_group("run options")
+    group.add_argument(
+        "--device",
+        default=None,
+        metavar="NAME",
+        help="Device type",
+        choices=Device.list(),
+    )
     group.add_argument(
         "--boot-args", default="", metavar="ARGS", help="extend boot arguments"
     )
+    group.add_argument(
+        "--timeouts",
+        metavar="K=V",
+        default={},
+        type=str,
+        help="timouts in minutes as action=duration",
+        action=KeyValueIntAction,
+        nargs="+",
+    )
 
     group = parser.add_argument_group("configuration files")
     group.add_argument(
